@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2020, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,7 +18,8 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
 import sys
@@ -36,28 +37,12 @@ from numba import cfunc
 import linecache
 import numba.types
 from math import pi
+import fluids.optional.spa
 
 
-'''Basic module which wraps all fluids functions with numba's jit.
-All other object - dicts, classes, etc - are not wrapped. Supports star 
-imports; so the same objects exported when importing from the main library
-will be imported from here. 
-
->>> from fluids.numba import *
-
-Note that because this needs to import fluids itself, fluids.numba
-needs to be imported separately; the following will cause an error:
-    
->>> import fluids
->>> fluids.numba # Won't work, has not been imported yet
-
-The correct syntax is as follows:
-
->>> import fluids.numba # Necessary
->>> from fluids.numba import * # May be used without first importing fluids
-'''
-
-caching = False
+caching = True
+extra_args_std = {'nogil': True, 'fastmath': True}
+extra_args_vec = {}
 __all__ = []
 
 __funcs = {}
@@ -77,7 +62,7 @@ def numba_exec_cacheable(source, lcs=None, gbls=None, cache_name='cache-safe'):
 
 # Some unfotrunate code duplication
 
-@numba.njit
+@numba.njit(cache=caching, **extra_args_std)
 def fpbspl(t, n, k, x, l, h, hh):
     h[0] = 1.0
     for j in range(1, k + 1):
@@ -90,7 +75,7 @@ def fpbspl(t, n, k, x, l, h, hh):
             h[i + 1] = f*(x - t[li - j])
     return h, hh
 
-@numba.njit
+@numba.njit(cache=caching, **extra_args_std)
 def init_w(t, k, x, lx, w):
     tb = t[k]
     n = len(t)
@@ -115,7 +100,7 @@ def init_w(t, k, x, lx, w):
         for j in range(k + 1):
             w[i][j] = h[j]
     return w
-@numba.njit
+@numba.njit(cache=caching, **extra_args_std)
 def cy_bispev(tx, ty, c, kx, ky, x, y):
     nx = len(tx)
     ny = len(ty)
@@ -154,12 +139,38 @@ def cy_bispev(tx, ty, c, kx, ky, x, y):
 
     
     
-@numba.njit
+@numba.njit(cache=caching, **extra_args_std)
 def bisplev(x, y, tck, dx=0, dy=0):
     tx, ty, c, kx, ky = tck
     return cy_bispev(tx, ty, c, kx, ky, np.array([x]), np.array([y]))[0]
 
 
+@numba.njit(cache=caching, **extra_args_std)
+def combinations(pool, r):
+    n = len(pool)
+#    indices = tuple(list(range(r)))
+    indices = np.arange(r)
+    empty = not (n and (0 < r <= n))
+
+    if not empty:
+#        yield [pool[i] for i in indices]
+#        yield (pool[i] for i in indices)
+        yield np.array([pool[i] for i in indices])
+
+    while not empty:
+        i = r - 1
+        while i >= 0 and indices[i] == i + n - r:
+            i -= 1
+        if i < 0:
+            empty = True
+        else:
+            indices[i] += 1
+            for j in range(i + 1, r):
+                indices[j] = indices[j - 1] + 1
+            result = np.array([pool[i] for i in indices])
+            yield result
+
+
 
 to_set_num = ['bisplev', 'cy_bispev', 'init_w', 'fpbspl']
 
@@ -207,27 +218,47 @@ def return_value_numpy(source):
 
 
 # Magic to make a lists into arrays
-list_mult_expr = r'\[ *([+-]?([0-9]+([.][0-9]*)?|[.][0-9]+)) *\] *\* *([a-zA-Z0-9]+)'
+list_mult_expr = r'\[ *([+-]?([0-9]+([.][0-9]*)?|[.][0-9]+)) *\] *\* *([a-zA-Z0-9_]+)'
 numpy_not_list_expr = r'np.full((\4,), \1)'
 
+match_prange = r'range\( *([a-zA-Z0-9_]+) *\) *: *# * (numba|NUMBA) *: *(prange|PRANGE)'
+sub_prange = r'prange(\1):'
 
-def transform_lists_to_arrays(module, to_change, __funcs, vec=False):
+def transform_lists_to_arrays(module, to_change, __funcs, vec=False, cache_blacklist=set([])):
     if vec:
         conv_fun = numba.vectorize
+        extra_args = extra_args_vec
     else:
-        conv_fun = numba.jit
-
+        conv_fun = numba.njit
+        extra_args = extra_args_std
     for s in to_change:
-        mod, func = s.split('.')
+        func = s.split('.')[-1]
+        mod = '.'.join(s.split('.')[:-1])
         fake_mod = __funcs[mod]
-        source = inspect.getsource(getattr(getattr(module, mod), func))
+
+        try:
+            real_mod = getattr(module, mod)
+        except:
+            real_mod = module
+            for s in mod.split('.'):
+                real_mod = getattr(real_mod, s)
+
+        orig_func = getattr(real_mod, func)
+        source = inspect.getsource(orig_func)
+        source = remove_for_numba(source) # do before anything else
         source = return_value_numpy(source)
         source = re.sub(list_mult_expr, numpy_not_list_expr, source)
-        source = remove_for_numba(source)
-#        print(source)
+        parallel = 'prange' in source
+        source = re.sub(match_prange, sub_prange, source)
+#        if 'Lindsay_Bromley' in source:
+#            print(source)
+#            print(parallel, 'hi', extra_args)
         numba_exec_cacheable(source, fake_mod.__dict__, fake_mod.__dict__)
         new_func = fake_mod.__dict__[func]
-        obj = conv_fun(cache=caching)(new_func)
+        do_cache = caching and func not in cache_blacklist
+        obj = conv_fun(cache=do_cache, parallel=parallel, **extra_args)(new_func)
+#        if 'Wilke_large' in source:
+#            print(id(obj), 'id')
         __funcs[func] = obj
         fake_mod.__dict__[func] = obj
         obj.__doc__ = ''
@@ -244,7 +275,7 @@ set_signatures = {}
 remove_comment_line = re.compile(r'''r?(['"])\1\1(.*?)\1{3}''', re.DOTALL)
 
 def remove_for_numba(source):
-    source = re.sub(r'''.*# ?numba ?: *(DELETE|delete).*''', '', source)
+    source = re.sub(r'''.*# ?(numba|NUMBA) ?: *(DELETE|delete).*''', '', source)
     source = re.sub(r'''#(.*)# ?(numba|NUMBA) ?: *(UNCOMMENT|uncomment).*''', r'\1', source)
     return source
 
@@ -289,21 +320,26 @@ def remove_branch(source, branch):
 skip = set([])
 total_skip = set([])
 skip_cache = set(['secant', 'brenth', 'py_solve'])
-
-bad_names = set(('__file__', '__name__', '__package__', '__cached__'))
+bad_names = set(('__file__', '__name__', '__package__', '__cached__', 'solve'))
 
 from fluids.numerics import SamePointError, UnconvergedError, NotBoundedError
 def create_numerics(replaced, vec=False):
-    
-    if vec:
-        conv_fun = numba.vectorize
-    else:
-        conv_fun = numba.jit
+    cache_unsuported = set(['brenth', 'newton_system', 'quad', 'quad_adaptive', 'fixed_quad_Gauss_Kronrod', 'py_lambertw', 'secant', 'lambertw', 'ridder', 'bisect'])
+#    if vec:
+#        conv_fun = numba.vectorize
+#    else:
+    # Not part of the public API - do not need to worry about the stricter
+    # numba.vectorize interface!
+    conv_fun = numba.njit
     
     NUMERICS_SUBMOD_COPY = importlib.util.find_spec('fluids.numerics')
     NUMERICS_SUBMOD = importlib.util.module_from_spec(NUMERICS_SUBMOD_COPY)
     NUMERICS_SUBMOD.IS_NUMBA = True
     NUMERICS_SUBMOD.FORCE_PYPY = True
+    NUMERICS_SUBMOD.numba = numba
+    NUMERICS_SUBMOD.jitclass = jitclass
+    NUMERICS_SUBMOD.njit = numba.njit
+    NUMERICS_SUBMOD.jit = numba.jit
     NUMERICS_SUBMOD.array_if_needed = np.array
     
     NUMERICS_SUBMOD_COPY.loader.exec_module(NUMERICS_SUBMOD)
@@ -322,10 +358,10 @@ def create_numerics(replaced, vec=False):
     
     NUMERICS_SUBMOD.py_solve = np.linalg.solve
     
-    bad_names = set(['tck_interp2d_linear', 'implementation_optimize_tck'])
+    bad_names = set(['tck_interp2d_linear', 'implementation_optimize_tck', 'py_solve'])
     bad_names.update(to_set_num)
     
-    solvers = ['secant', 'brenth', 'newton', 'ridder', 'newton_system'] # 
+    solvers = ['secant', 'brenth', 'newton', 'halley', 'ridder', 'newton_system', 'solve_2_direct', 'solve_3_direct', 'solve_4_direct', 'basic_damping', 'bisect'] # 
     for s in solvers:
         source = inspect.getsource(getattr(NUMERICS_SUBMOD, s))
         source = source.replace(', kwargs={}', '').replace(', **kwargs', '').replace(', kwargs=kwargs', '')
@@ -336,7 +372,9 @@ def create_numerics(replaced, vec=False):
         source = source.replace(', value=%s" %(maxiter, x)', '"')
         source = re.sub(r'''UnconvergedError\(.*''', '''UnconvergedError("Failed to converge")''', source) # Gotta keep errors all one one line
         source = remove_for_numba(source)
-#        if s == 'newton_system':
+        source = re.sub(list_mult_expr, numpy_not_list_expr, source)
+
+#        if any(i in s for i in ('bisect', 'solve_2_direct', 'basic_damping')):
 #            print(source)
         numba_exec_cacheable(source, NUMERICS_SUBMOD.__dict__, NUMERICS_SUBMOD.__dict__)
 
@@ -347,11 +385,12 @@ def create_numerics(replaced, vec=False):
         if name not in bad_names:
             obj = getattr(NUMERICS_SUBMOD, name)
             if isinstance(obj, types.FunctionType):
+                do_cache = caching and name not in cache_unsuported
 #                forceobj = name in numerics_forceobj
 #                forceobj = False
                 # cache=not forceobj 
                 # cache=name not in skip_cache
-                obj = numba.jit(cache=caching, forceobj=False)(obj)
+                obj = conv_fun(cache=do_cache, **extra_args_std)(obj)
                 NUMERICS_SUBMOD.__dict__[name] = obj
                 replaced[name] = obj
 #                globals()[name] = objs
@@ -361,64 +400,83 @@ def create_numerics(replaced, vec=False):
             
     replaced['bisplev'] = replaced['py_bisplev'] = NUMERICS_SUBMOD.__dict__['bisplev'] = bisplev
 #    replaced['lambertw'] = NUMERICS_SUBMOD.__dict__['lambertw'] = NUMERICS_SUBMOD.__dict__['py_lambertw']
-    for s in ('ellipe', 'gammaincc', 'gamma', 'i1', 'i0', 'k1', 'k0', 'iv', 'hyp2f1', 'erf'):
+    for s in ('ellipe', 'gammaincc', 'gamma', 'i1', 'i0', 'k1', 'k0', 'iv', 'hyp2f1', 'erf', 'ellipkinc', 'ellipeinc'):
         replaced[s] = NUMERICS_SUBMOD.__dict__[s]
-    
-#    replaced['splev'] = NUMERICS_SUBMOD.__dict__['splev']  = replaced['py_splev']
-#    replaced['lambertw'] = NUMERICS_SUBMOD.__dict__['lambertw'] = replaced['py_lambertw']
-    
-#    @numba.njit
-#    def newton_err(x):
-#        return np.abs(np.array(x), dtype=np.float64).sum()
-#    replaced['newton_err'] = NUMERICS_SUBMOD.newton_err = newton_err
     return replaced, NUMERICS_SUBMOD
 
-replaced = {'sum': np.sum}
+replaced = {'sum': np.sum, 'combinations': combinations, 'np': np}
 replaced, NUMERICS_SUBMOD = create_numerics(replaced, vec=False)
+numerics_dict = replaced
 numerics = NUMERICS_SUBMOD
 #old_numerics = sys.modules['fluids.numerics']
 #sys.modules['fluids.numerics'] = numerics
 normal = normal_fluids
 
 
-def transform_module(normal, __funcs, replaced, vec=False):
+def transform_module(normal, __funcs, replaced, vec=False, blacklist=frozenset([]),
+                     cache_blacklist=set([])):
     new_mods = []
-    
     if vec:
         conv_fun = numba.vectorize
+        extra_args = extra_args_vec
     else:
-        conv_fun = numba.jit
+        conv_fun = numba.njit
+        extra_args = extra_args_std
     mod_name = normal.__name__
     # Run module-by-module. Expensive, as we need to create module copies
-    for mod in normal.submodules:
+    try:
+        all_submodules = normal.all_submodules()
+    except:
+        all_submodules = normal.submodules
+    for mod in all_submodules:
+        #print(all_submodules, mod)
         SUBMOD_COPY = importlib.util.find_spec(mod.__name__)
         SUBMOD = importlib.util.module_from_spec(SUBMOD_COPY)
         SUBMOD.IS_NUMBA = True
+        SUBMOD.numba = numba
+        SUBMOD.jitclass = jitclass
+        SUBMOD.njit = numba.njit
+        SUBMOD.jit = numba.jit
+        SUBMOD.prange = numba.prange
+        
+        if vec:
+            SUBMOD.IS_NUMBA_VEC = True
         SUBMOD_COPY.loader.exec_module(SUBMOD)
         SUBMOD.np = np
         
         SUBMOD.__dict__.update(replaced)
         new_mods.append(SUBMOD)
-        
-        __funcs[mod.__name__.split(mod_name + '.')[1]] = SUBMOD
-        
-        names = list(SUBMOD.__all__)
+        __funcs[mod.__name__.split('.')[-1]] = SUBMOD # fluids.numba.optional.spa
+        __funcs['.'.join(mod.__name__.split('.')[:-1])] = SUBMOD # set fluids.optional.spa fluids.numba.spa
+        __funcs['.'.join(mod.__name__.split('.')[-2:])] = SUBMOD # set 'optional.spa' in the dict too
         try:
-            names += SUBMOD.__numba_additional_funcs__
+            names = list(SUBMOD.__all__)
         except:
-            pass
+            names = []
+        for mod_obj_name in dir(SUBMOD):
+            obj = getattr(SUBMOD, mod_obj_name)
+            if isinstance(obj, types.FunctionType):
+                if mod_obj_name not in names:
+                    # Check if the function is local to the module
+                    if obj.__module__ == SUBMOD.__name__:
+                        names.append(mod_obj_name)
+
+        # try:
+        #     names += SUBMOD.__numba_additional_funcs__
+        # except:
+        #     pass
     
         new_objs = []
         for name in names:
             obj = getattr(SUBMOD, name)
             if isinstance(obj, types.FunctionType):
                 nopython = name not in skip
-                if name not in total_skip:
+                if name not in total_skip and name not in blacklist:
                     obj = conv_fun(#set_signatures.get(name, None), 
-                            nopython=nopython,
+#                            nopython=nopython,
                             #forceobj=not nopython,
-                                    fastmath=nopython,#Parallel=nopython
-                                    cache=caching)(obj)
+#                                    fastmath=True,#Parallel=nopython
+                                    cache=(caching and name not in cache_blacklist), **extra_args)(obj)
                 SUBMOD.__dict__[name] = obj
                 new_objs.append(obj)
             __funcs[name] = obj
@@ -430,9 +488,14 @@ def transform_module(normal, __funcs, replaced, vec=False):
                 obj_type = type(obj)
                 if obj_type is list and len(obj) and type(obj[0]) in (float, int, complex):
                     module_constants_changed_type[arr_name] = np.array(obj)
-                elif obj_type is list and len(obj) and all([
-                        (type(r) is list and len(r) and type(r[0]) in (float, int, complex)) for r in obj]):
-                    module_constants_changed_type[arr_name] = np.array(obj)
+                elif (obj_type is list and len(obj) and all([
+                        (type(r) is list and len(r) and type(r[0]) in (float, int, complex)) for r in obj])):
+                    if len(set([len(r) for r in obj])) == 1:
+                        # All same size - nice numpy array
+                        module_constants_changed_type[arr_name] = np.array(obj)
+                    else:
+                        # Tuple of different size numpy arrays
+                        module_constants_changed_type[arr_name] = tuple(np.array(v) for v in obj)
                 elif obj_type in (set, frozenset):
                     module_constants_changed_type[arr_name] = tuple(obj)
                 elif obj_type is dict:
@@ -444,19 +507,16 @@ def transform_module(normal, __funcs, replaced, vec=False):
                     except:
                         print(arr_name, 'failed')
                         pass
-        
-##        print(SUBMOD)
-#        if 'h0_Gorenflow_1993' in SUBMOD.__dict__:
-##        if hasattr, ''):
-#            module_constants_changed_type['h0_Gorenflow_1993'] =  numba_dict(SUBMOD.h0_Gorenflow_1993)
-#            #SUBMOD.__dict__['h0_Gorenflow_1993'] = numba_dict(SUBMOD.h0_Gorenflow_1993)
-#
                 
         SUBMOD.__dict__.update(module_constants_changed_type)
         __funcs.update(module_constants_changed_type)
     
         if not vec:
             for t in new_objs:
+                #if normal.__name__ == 'chemicals':
+                #    if 'iapws' not in all_submodules[-1].__name__:
+                #        print(new_objs, t)
+                #        1/0
                 try:
                     glob = t.py_func.__globals__
                 except:
@@ -466,6 +526,10 @@ def transform_module(normal, __funcs, replaced, vec=False):
                 glob.update(replaced)
     
     # Do our best to allow functions to be found
+    if '__file__' in __funcs:
+        del __funcs['__file__']
+    if '__file__' in replaced:
+        del replaced['__file__']
     for mod in new_mods:
         mod.__dict__.update(__funcs)
         mod.__dict__.update(replaced)
@@ -474,74 +538,42 @@ def transform_module(normal, __funcs, replaced, vec=False):
 
 
 def transform_complete(replaced, __funcs, __all__, normal, vec=False):
+    cache_blacklist = set(['Stichlmair_flood', 'airmass', 
+   'Spitzglass_high', '_to_solve_Spitzglass_high',
+   '_to_solve_Spitzglass_low', 'Spitzglass_low',
+   'Oliphant', '_to_solve_Oliphant',
+   'P_isothermal_critical_flow', 'P_upstream_isothermal_critical_flow',
+   'isothermal_gas_err_P1', 'isothermal_gas_err_P2', 'isothermal_gas_err_P2_basis', 'isothermal_gas_err_D', 'isothermal_gas',
+   'v_terminal', 'differential_pressure_meter_solver', 'err_dp_meter_solver_P1', 'err_dp_meter_solver_D2',
+   'err_dp_meter_solver_P2', 'err_dp_meter_solver_m', 'V_horiz_spherical', 'V_horiz_torispherical',
+   'Prandtl_von_Karman_Nikuradse', 'plate_enlargement_factor', 'Stichlmair_wet', 'V_from_h',
+   'SA_partial_horiz_spherical_head', '_SA_partial_horiz_spherical_head_to_int',
+   '_SA_partial_horiz_ellipsoidal_head_to_int', '_SA_partial_horiz_ellipsoidal_head_limits', 'SA_partial_horiz_ellipsoidal_head',
+   '_SA_partial_horiz_guppy_head_to_int', 'SA_partial_horiz_guppy_head', 'SA_partial_horiz_torispherical_head',
+   'SA_from_h'])
     if vec:
         conv_fun = numba.vectorize
+        extra_args = extra_args_vec
     else:
-        conv_fun = numba.jit
-    new_mods = transform_module(normal, __funcs, replaced, vec=vec)
+        conv_fun = numba.njit
+        extra_args = extra_args_std
+    new_mods = transform_module(normal, __funcs, replaced, vec=vec, cache_blacklist=cache_blacklist)
 
     
-    # Do some classes by hand
-    
-    PlateExchanger_spec = [
-        ('pitch', float64),
-        ('beta', float64),
-        ('gamma', float64),
-        ('a', float64),
-        ('amplitude', float64),               
-        ('wavelength', float64),               
-        ('b', float64),               
-        ('chevron_angle', float64),               
-        ('inclination_angle', float64),               
-        ('plate_corrugation_aspect_ratio', float64),               
-        ('plate_enlargement_factor', float64),               
-        ('D_eq', float64),               
-        ('D_hydraulic', float64),               
-        ('width', float64),               
-        ('length', float64),               
-        ('thickness', float64),               
-        ('d_port', float64),               
-        ('plates', float64),               
-        ('length_port', float64),               
-        ('A_plate_surface', float64),               
-        ('A_heat_transfer', float64),               
-        ('A_channel_flow', float64),               
-        ('channels', float64),               
-        ('channels_per_fluid', float64),               
-    ]
-    
-    
-    HelicalCoil_spec = [(k, float64) for k in 
-                        ('Do', 'Dt', 'Di', 'Do_total', 'N', 'pitch', 'H', 'H_tot', 
-                         'tube_circumference', 'tube_length', 'surface_area', 'helix_angle',
-                         'curvature', 'total_inlet_area', 'total_volume', 'inner_surface_area',
-                         'inlet_area', 'inner_volume', 'annulus_area', 'annulus_volume')]
-    
-    ATMOSPHERE_1976_spec = [(k, float64) for k in 
-                        ('Z', 'dT', 'H', 'T_layer', 'T_increase', 'P_layer', 'H_layer', 'H_above_layer', 
-                         'T', 'P', 'rho', 'v_sonic',
-                         'mu', 'k', 'g', 'R')]
-    
     to_change = ['packed_tower._Stichlmair_flood_f_and_jac', 
-                 'packed_tower.Stichlmair_flood']
-    transform_lists_to_arrays(normal_fluids, to_change, __funcs, vec=vec)
+                 'packed_tower.Stichlmair_flood', 'compressible.isothermal_gas', 
+                 'fittings.Darby3K', 'fittings.Hooper2K', 'geometry.SA_partial_horiz_torispherical_head',
+                 'optional.spa.solar_position', 'optional.spa.longitude_obliquity_nutation',
+                 'optional.spa.transit_sunrise_sunset',
+                 'fittings.bend_rounded_Crane', 'geometry.tank_from_two_specs_err',
+                 ]
+    transform_lists_to_arrays(normal_fluids, to_change, __funcs, vec=vec, cache_blacklist=cache_blacklist)
     
     
     # AvailableMethods  will be removed in the future in favor of non-numba only 
     # calls to method functions
     
-    to_change_AvailableMethods = ['friction.friction_factor_curved', 'friction.friction_factor',
-     'packed_bed.dP_packed_bed', 'two_phase.two_phase_dP', 'drag.drag_sphere',
-     'two_phase_voidage.liquid_gas_voidage', 'two_phase_voidage.gas_liquid_viscosity']
-    
-    
-    to_change_full_output = ['two_phase.Mandhane_Gregory_Aziz_regime',
-                             'two_phase.Taitel_Dukler_regime']
-    
-    to_change = {k: 'AvailableMethods' for k in to_change_AvailableMethods}
-    to_change.update({k: 'full_output' for k in to_change_full_output})
-    to_change['fittings.Darby3K'] = 'name in Darby: # NUMBA: DELETE'
-    to_change['fittings.Hooper2K'] = 'name in Hooper: # NUMBA: DELETE'
+    to_change = {}
     to_change['friction.roughness_Farshad'] = 'ID in _Farshad_roughness'
     
     for s, bad_branch in to_change.items():
@@ -552,53 +584,57 @@ def transform_complete(replaced, __funcs, __all__, normal, vec=False):
         source = remove_for_numba(source)
         numba_exec_cacheable(source, fake_mod.__dict__, fake_mod.__dict__)
         new_func = fake_mod.__dict__[func]
-        obj = conv_fun(cache=caching)(new_func)
+        obj = conv_fun(cache=caching, **extra_args)(new_func)
         __funcs[func] = obj
-#        globals()[func] = obj
-        obj.__doc__ = ''
-        
-        
-    to_change = ['compressible.isothermal_gas']
-    for s in to_change:
-        mod, func = s.split('.')
-        source = inspect.getsource(getattr(getattr(normal_fluids, mod), func))
-        fake_mod = __funcs[mod]
-        source = remove_for_numba(source)
-        numba_exec_cacheable(source, fake_mod.__dict__, fake_mod.__dict__)
-        new_func = fake_mod.__dict__[func]
-        obj = conv_fun(cache=caching)(new_func)
-        __funcs[func] = obj
-#        globals()[func] = obj
         obj.__doc__ = ''
     
+
+    # Do some classes by hand
+    PlateExchanger_spec = [(k, float64) for k in ('pitch', 'beta', 'gamma', 'a', 'amplitude', 'wavelength', 
+                           'b', 'chevron_angle', 'inclination_angle', 'plate_corrugation_aspect_ratio',
+                           'plate_enlargement_factor', 'D_eq', 'D_hydraulic', 'width', 'length', 'thickness',
+                           'd_port', 'plates', 'length_port', 'A_plate_surface', 'A_heat_transfer',
+                           'A_channel_flow', 'channels', 'channels_per_fluid')]
+    PlateExchanger_spec.append(('chevron_angles', numba.types.UniTuple(numba.types.float64, 2)))
     
+    HelicalCoil_spec = [(k, float64) for k in 
+                        ('Do', 'Dt', 'Di', 'Do_total', 'N', 'pitch', 'H', 'H_total', 
+                         'tube_circumference', 'tube_length', 'surface_area', 'helix_angle',
+                         'curvature', 'total_inlet_area', 'total_volume', 'inner_surface_area',
+                         'inlet_area', 'inner_volume', 'annulus_area', 'annulus_volume')]
     
-    # Almost there but one argument has a variable type
-    #PlateExchanger = jitclass(PlateExchanger_spec)(getattr(__funcs['geometry'], 'PlateExchanger'))
-    #HelicalCoil = jitclass(HelicalCoil_spec)(getattr(__funcs['geometry'], 'HelicalCoil'))
+    ATMOSPHERE_1976_spec = [(k, float64) for k in 
+                        ('Z', 'dT', 'H', 'T_layer', 'T_increase', 'P_layer', 'H_layer', 'H_above_layer', 
+                         'T', 'P', 'rho', 'v_sonic',
+                         'mu', 'k', 'g', 'R')]
+    
+#    # No string support
+#    PlateExchanger = jitclass(PlateExchanger_spec)(getattr(__funcs['geometry'], 'PlateExchanger'))
+#    __funcs['PlateExchanger'] = __funcs['geometry'].PlateExchanger = PlateExchanger
+    
+    HelicalCoil = jitclass(HelicalCoil_spec)(getattr(__funcs['geometry'], 'HelicalCoil'))
+    __funcs['HelicalCoil'] = __funcs['geometry'].HelicalCoil = HelicalCoil
+
     ATMOSPHERE_1976 = jitclass(ATMOSPHERE_1976_spec)(getattr(__funcs['atmosphere'], 'ATMOSPHERE_1976'))
     __funcs['ATMOSPHERE_1976'] = __funcs['atmosphere'].ATMOSPHERE_1976 = ATMOSPHERE_1976
     
     
     # Not needed
     __funcs['friction'].Colebrook = __funcs['Colebrook'] = __funcs['Clamond']
-    #for k in ('flow_meter', 'fittings', 'two_phase', 'friction'):
-    #    __funcs[k].friction_factor = __funcs['friction_factor'] = __funcs['Clamond']
-    #__funcs['PlateExchanger'] = __funcs['geometry'].PlateExchanger = PlateExchanger
-    #__funcs['HelicalCoil'] = __funcs['geometry'].HelicalCoil = HelicalCoil
     
     # Works but 50% slower
     #__funcs['geometry']._V_horiz_spherical_toint = __funcs['_V_horiz_spherical_toint'] = cfunc("float64(float64, float64, float64, float64)")(normal_fluids.geometry._V_horiz_spherical_toint)
     
-    # ex = fluids.numba.geometry.PlateExchanger(amplitude=5E-4, wavelength=3.7E-3, length=1.2, width=.3, d_port=.05, plates=51, thickness=1e-10)
-    #fluids.numba.geometry.HelicalCoil(Do_total=32.0, H_total=22.0, pitch=5.0, Dt=2.0, Di=1.8)
-    
     for mod in new_mods:
         mod.__dict__.update(__funcs)
+        try:
+            __all__.extend(mod.__all__)
+        except AttributeError:
+            pass
 
 transform_complete(replaced, __funcs, __all__, normal, vec=False)
 
-
+numbafied_fluids_functions = __funcs
 globals().update(__funcs)
 globals().update(replaced)
 
