@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,10 +18,11 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import log
+from math import log, sqrt
 from fluids.constants import hp
 from fluids.numerics import interp, tck_interp2d_linear, bisplev
 
@@ -30,7 +31,8 @@ __all__ = ['VFD_efficiency', 'CSA_motor_efficiency', 'motor_efficiency_underload
 'specific_speed', 'specific_diameter', 'speed_synchronous', 'nema_sizes',
 'nema_sizes_hp', 'motor_round_size', 'nema_min_P', 'nema_high_P', 'plug_types',
 'voltages_1_phase_residential', 'voltages_3_phase', 'frequencies',
-'residential_power', 'industrial_power', 'current_ideal']
+'residential_power', 'industrial_power', 'current_ideal',
+'CountryPower']
 
 
 
@@ -187,7 +189,7 @@ def VFD_efficiency(P, load=1):
         P = 400.0
     if load < 0.016:
         load = 0.016
-    return round(bisplev(load, P, VFD_efficiency_tck), 4)
+    return round(float(bisplev(load, P, VFD_efficiency_tck)), 4)
 
 
 nema_sizes_hp = [0.25, 0.3333333333333333, 0.5, 0.75, 1.0, 1.5, 2.0, 3.0, 4.0,
@@ -234,7 +236,7 @@ def motor_round_size(P):
     for P_actual in nema_sizes:
         if P_actual >= P:
             return P_actual
-    raise Exception('Required power is larger than can be provided with one motor')
+    raise ValueError('Required power is larger than can be provided with one motor')
 
 
 nema_high_P = [1.0, 1.5, 2.0, 3.0, 4.0, 5.0, 5.5, 7.5, 10.0, 15.0, 20.0, 25.0, 30.0, 40.0, 50.0, 60.0, 75.0, 100.0, 125.0, 150.0, 175.0, 200.0]
@@ -464,7 +466,7 @@ def specific_speed(Q, H, n=3600.):
     ----------
     .. [1] HI 1.3 Rotodynamic Centrifugal Pumps for Design and Applications
     '''
-    return n*Q**0.5/H**0.75
+    return n*sqrt(Q)/H**0.75
 
 
 def specific_diameter(Q, H, D):
@@ -495,14 +497,14 @@ def specific_diameter(Q, H, D):
     Examples
     --------
     >>> specific_diameter(Q=0.1, H=10., D=0.1)
-    0.5623413251903491
+    0.5623413251903492
 
     References
     ----------
     .. [1] Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
        Eighth Edition. McGraw-Hill Professional, 2007.
     '''
-    return D*H**0.25*Q**-0.5
+    return D*sqrt(sqrt(H)/Q)
 
 
 def speed_synchronous(f, poles=2, phase=3):
@@ -593,17 +595,17 @@ def current_ideal(P, V, phase=3, PF=1):
        http://ecmweb.com/basics/calculating-single-and-3-phase-parameters.
     '''
     if phase not in [1, 3]:
-        raise Exception('Only 1 and 3 phase power supported')
+        raise ValueError('Only 1 and 3 phase power supported')
     if phase == 3:
-        return P/(V*3**0.5*PF)
+        return P/(V*sqrt(3)*PF)
     else:
         return P/(V*PF)
 
 
 class CountryPower(object):
-    '''Class to hold information on the residential or electrical data of
-    a country. Data from Wikipedia, obtained in 2017.
-    
+    """Class to hold information on the residential or electrical data of a
+    country. Data from Wikipedia, obtained in 2017.
+
     Parameters
     ----------
     plugs : tuple(str)
@@ -615,7 +617,7 @@ class CountryPower(object):
         The electrical frequency in use in the country, [Hz]
     country : str
         The name of the country, [-]
-        '''
+    """
     __slots__ = ('plugs', 'voltage', 'freq', 'country')
     
     def __repr__(self):
