@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,10 +18,11 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import exp
+from math import exp, sqrt
 from fluids.constants import psi, inch, atm
 from fluids.compressible import is_critical_flow
 from fluids.numerics import interp, tck_interp2d_linear, bisplev
@@ -77,7 +78,7 @@ def API520_round_size(A):
     for area in API526_A:
         if area >= A:
             return area
-    raise Exception('Required relief area is larger than can be provided with one valve')
+    raise ValueError('Required relief area is larger than can be provided with one valve')
 
 
 def API520_C(k):
@@ -122,9 +123,9 @@ def API520_C(k):
     .. [1] API Standard 520, Part 1 - Sizing and Selection.
     '''
     if k != 1:
-        return 0.03948*( k*(2./(k+1.))**((k+1.)/(k-1.)) )**0.5
+        return 0.03948*sqrt(k*(2./(k+1.))**((k+1.)/(k-1.)))
     else:
-        return 0.03948*(1./exp(1))**0.5
+        return 0.03948*sqrt(1./exp(1))
 
 
 def API520_F2(k, P1, P2):
@@ -170,7 +171,7 @@ def API520_F2(k, P1, P2):
     .. [1] API Standard 520, Part 1 - Sizing and Selection.
     '''
     r = P2/P1
-    return ( k/(k-1)*r**(2./k) * ((1-r**((k-1.)/k))/(1.-r)) )**0.5
+    return sqrt(k/(k-1)*r**(2./k) * ((1-r**((k-1.)/k))/(1.-r)))
 
 
 def API520_Kv(Re):
@@ -217,7 +218,7 @@ def API520_Kv(Re):
     ----------
     .. [1] API Standard 520, Part 1 - Sizing and Selection.
     '''
-    return (0.9935 + 2.878/Re**0.5 + 342.75/Re**1.5)**-1.0
+    return (0.9935 + 2.878/sqrt(Re) + 342.75/Re**1.5)**-1.0
 
 
 def API520_N(P1):
@@ -353,9 +354,9 @@ def API520_SH(T1, P1):
     .. [1] API Standard 520, Part 1 - Sizing and Selection.
     '''
     if P1 > 20780325.0: # 20679E3+atm
-        raise Exception('For P above 20679 kPag, use the critical flow model')
+        raise ValueError('For P above 20679 kPag, use the critical flow model')
     if T1 > 922.15:
-        raise Exception('Superheat cannot be above 649 degrees Celcius')
+        raise ValueError('Superheat cannot be above 649 degrees Celcius')
     if T1 < 422.15:
         return 1. # No superheat under 15 psig
     return float(bisplev(T1, P1, API520_KSH_tck))
@@ -490,13 +491,13 @@ def API520_B(Pset, Pback, overpressure=0.1):
     '''
     gauge_backpressure = (Pback-atm)/(Pset-atm)*100.0 # in percent
     if overpressure not in (0.1, 0.16, 0.21):
-        raise Exception('Only overpressure of 10%, 16%, or 21% are permitted')
+        raise ValueError('Only overpressure of 10%, 16%, or 21% are permitted')
     if (overpressure == 0.1 and gauge_backpressure < 30.0) or (
         overpressure == 0.16 and gauge_backpressure < 38.0) or (
         overpressure == 0.21 and gauge_backpressure < 50.0):
         return 1.0
     elif gauge_backpressure > 50.0:
-        raise Exception('Gauge pressure must be < 50%')
+        raise ValueError('Gauge pressure must be < 50%')
     if overpressure == 0.16:
         Kb = interp(gauge_backpressure, Kb_16_over_x, Kb_16_over_y)
     elif overpressure == 0.1:
@@ -581,10 +582,10 @@ def API520_A_g(m, T, Z, MW, k, P1, P2=101325, Kd=0.975, Kb=1, Kc=1):
     m = m*3600. # kg/s to kg/hr
     if is_critical_flow(P1, P2, k):
         C = API520_C(k)
-        A = m/(C*Kd*Kb*Kc*P1)*(T*Z/MW)**0.5
+        A = m/(C*Kd*Kb*Kc*P1)*sqrt(T*Z/MW)
     else:
         F2 = API520_F2(k, P1, P2)
-        A = 17.9*m/(F2*Kd*Kc)*(T*Z/(MW*P1*(P1-P2)))**0.5
+        A = 17.9*m/(F2*Kd*Kc)*sqrt(T*Z/(MW*P1*(P1-P2)))
     return A*0.001**2 # convert mm^2 to m^2
 
 
